@@ -36,7 +36,11 @@ def get_distribution_version_info(filename=version_info_filename):
         distribution.
 
         """
-    version_info = {}
+    version_info = {
+            'release_date': "UNKNOWN",
+            'version': "UNKNOWN",
+            'maintainer': "UNKNOWN",
+            }
 
     try:
         distribution = pkg_resources.get_distribution(distribution_name)
@@ -52,8 +56,7 @@ def get_distribution_version_info(filename=version_info_filename):
 
 version_info = get_distribution_version_info()
 
-version_installed = version_info.get('version', "UNKNOWN")
-
+version_installed = version_info['version']
 
 
 rfc822_person_regex = re.compile(
@@ -133,7 +136,7 @@ def make_year_range(begin_year, end_date=None):
     return year_range
 
 copyright_year_begin = "2001"
-build_date = version_info.get('release_date', "UNKNOWN")
+build_date = version_info['release_date']
 copyright_year_range = make_year_range(copyright_year_begin, build_date)
 
 copyright = "Copyright © {year_range} {author} and others".format(
