@@ -3,7 +3,7 @@
 # test/__init__.py
 # Part of ‘python-daemon’, an implementation of PEP 3143.
 #
-# Copyright © 2008–2014 Ben Finney <ben+python@benfinney.id.au>
+# Copyright © 2008–2015 Ben Finney <ben+python@benfinney.id.au>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the Apache License, version 2.0 as published by the
@@ -13,12 +13,7 @@
 """ Unit test suite for ‘daemon’ package.
     """
 
-from __future__ import unicode_literals
-
-import scaffold
-
-
-suite = scaffold.make_suite()
+from __future__ import (absolute_import, unicode_literals)
 
 
 # Local variables:
