@@ -258,8 +258,8 @@ class metadata_content_TestCase(scaffold.TestCase):
 try:
     FileNotFoundError
 except NameError:
-    # Python 2 uses OSError.
-    FileNotFoundError = functools.partial(OSError, errno.ENOENT)
+    # Python 2 uses IOError.
+    FileNotFoundError = functools.partial(IOError, errno.ENOENT)
 
 version_info_filename = "version_info.json"
 
