@@ -14,14 +14,9 @@
 
 from __future__ import (absolute_import, unicode_literals)
 
-try:
-    # Python 3 standard library.
-    import builtins
-except ImportError:
-    # Python 2 standard library.
-    import __builtin__ as builtins
 import os
 import os.path
+import io
 import errno
 import functools
 import collections
@@ -719,8 +714,8 @@ try:
     PermissionError
 except NameError:
     # Python 2 uses OSError.
-    FileNotFoundError = functools.partial(OSError, errno.ENOENT)
-    PermissionError = functools.partial(OSError, errno.EPERM)
+    FileNotFoundError = functools.partial(IOError, errno.ENOENT)
+    PermissionError = functools.partial(IOError, errno.EPERM)
 
 fake_version_info = {
         'release_date': "2001-01-01", 'version': "2.0",
@@ -729,8 +724,6 @@ fake_version_info = {
 
 @mock.patch.object(
         version, "get_latest_version", return_value=fake_version_info)
-@mock.patch.object(
-        version, "changelog_to_version_info_collection")
 class generate_version_info_from_changelog_TestCase(
         testscenarios.WithScenarios, testtools.TestCase):
     """ Test cases for ‘generate_version_info_from_changelog’ function. """
@@ -764,44 +757,64 @@ class generate_version_info_from_changelog_TestCase(
 
         self.fake_changelog_file_path = tempfile.mktemp()
 
-        def fake_open(filename, mode='rt', buffering=None):
-            if filename == self.fake_changelog_file_path:
+        def fake_open(filespec, *args, **kwargs):
+            if filespec == self.fake_changelog_file_path:
                 side_effect = self.fake_open_side_effects[self.open_scenario]
-                if hasattr(side_effect, '__call__'):
-                    result = side_effect(filename, mode, buffering)
+                if callable(side_effect):
+                    result = side_effect()
                 else:
                     raise side_effect
             else:
                 result = StringIO()
             return result
 
-        mock_open = mock.mock_open()
-        mock_open.side_effect = fake_open
+        func_patcher_io_open = mock.patch.object(
+                io, "open")
+        func_patcher_io_open.start()
+        self.addCleanup(func_patcher_io_open.stop)
+        io.open.side_effect = fake_open
 
-        func_patcher_builtin_open = mock.patch.object(
-                builtins, "open",
-                new=mock_open)
-        func_patcher_builtin_open.start()
-        self.addCleanup(func_patcher_builtin_open.stop)
+        self.file_encoding = "utf-8"
+
+        func_patcher_changelog_to_version_info_collection = mock.patch.object(
+                version, "changelog_to_version_info_collection")
+        func_patcher_changelog_to_version_info_collection.start()
+        self.addCleanup(func_patcher_changelog_to_version_info_collection.stop)
+        if hasattr(self, 'fake_versions_json'):
+            version.changelog_to_version_info_collection.return_value = (
+                    self.fake_versions_json.encode(self.file_encoding))
 
     def test_returns_empty_collection_on_read_error(
             self,
-            mock_func_changelog_to_version_info, mock_func_get_latest_version):
+            mock_func_get_latest_version):
         """ Should return empty collection on error reading changelog. """
         test_error = PermissionError("Not for you")
-        mock_func_changelog_to_version_info.side_effect = test_error
+        version.changelog_to_version_info_collection.side_effect = test_error
         result = version.generate_version_info_from_changelog(
                 self.fake_changelog_file_path)
         expected_result = {}
         self.assertDictEqual(expected_result, result)
 
+    def test_opens_file_with_expected_encoding(
+            self,
+            mock_func_get_latest_version):
+        """ Should open changelog file in text mode with expected encoding. """
+        result = version.generate_version_info_from_changelog(
+                self.fake_changelog_file_path)
+        expected_file_path = self.fake_changelog_file_path
+        expected_open_mode = 'rt'
+        expected_encoding = self.file_encoding
+        (open_args_positional, open_args_kwargs) = io.open.call_args
+        (open_args_filespec, open_args_mode) = open_args_positional[:2]
+        open_args_encoding = open_args_kwargs['encoding']
+        self.assertEqual(expected_file_path, open_args_filespec)
+        self.assertEqual(expected_open_mode, open_args_mode)
+        self.assertEqual(expected_encoding, open_args_encoding)
+
     def test_returns_expected_result(
             self,
-            mock_func_changelog_to_version_info, mock_func_get_latest_version):
+            mock_func_get_latest_version):
         """ Should return expected result. """
-        if hasattr(self, 'fake_versions_json'):
-            mock_func_changelog_to_version_info.return_value = (
-                    self.fake_versions_json.encode('utf-8'))
         result = version.generate_version_info_from_changelog(
                 self.fake_changelog_file_path)
         self.assertEqual(self.expected_result, result)
@@ -1143,37 +1156,22 @@ class has_changelog_TestCase(
         testscenarios.WithScenarios, testtools.TestCase):
     """ Test cases for ‘has_changelog’ function. """
 
-    fake_open_side_effects = {
-            'success': (
-                lambda testcase, *args, **kwargs:
-                    testcase.fake_changelog_file),
-            'file not found': FileNotFoundError(),
-            'permission denied': PermissionError(),
-            }
-
     fake_os_path_exists_side_effects = {
             'true': (lambda path: True),
             'false': (lambda path: False),
             }
 
     scenarios = [
-            ('changelog exists', {
-                'os_path_exists_scenario': 'true',
-                'open_scenario': 'success',
-                'expected_result': True,
-                }),
             ('no changelog path', {
                 'changelog_path': None,
                 'expected_result': False,
                 }),
+            ('changelog exists', {
+                'os_path_exists_scenario': 'true',
+                'expected_result': True,
+                }),
             ('changelog not found', {
                 'os_path_exists_scenario': 'false',
-                'open_scenario': 'file not found',
-                'expected_result': False,
-                }),
-            ('changelog not readable', {
-                'os_path_exists_scenario': 'true',
-                'open_scenario': 'permission denied',
                 'expected_result': False,
                 }),
             ]
@@ -1197,29 +1195,11 @@ class has_changelog_TestCase(
         version.get_changelog_path.return_value = self.fake_changelog_file_path
         self.fake_changelog_file = StringIO()
 
-        def fake_open(filename, mode='rt', buffering=None):
-            if filename == self.fake_changelog_file_path:
-                side_effect = self.fake_open_side_effects[self.open_scenario]
-                if hasattr(side_effect, '__call__'):
-                    result = side_effect(self, filename, mode, buffering)
-                else:
-                    raise side_effect
-            else:
-                result = StringIO()
-            return result
-
-        mock_open = mock.mock_open()
-        mock_open.side_effect = fake_open
-
-        self.func_patcher_builtin_open = mock.patch.object(
-                builtins, "open",
-                new=mock_open)
-
         def fake_os_path_exists(path):
-            if filename == self.fake_changelog_file_path:
+            if path == self.fake_changelog_file_path:
                 side_effect = self.fake_os_path_exists_side_effects[
                         self.os_path_exists_scenario]
-                if hasattr(side_effect, '__call__'):
+                if callable(side_effect):
                     result = side_effect(path)
                 else:
                     raise side_effect
@@ -1231,29 +1211,19 @@ class has_changelog_TestCase(
                 os.path, "exists")
         func_patcher_os_path_exists.start()
         self.addCleanup(func_patcher_os_path_exists.stop)
-        func_patcher_os_path_exists.side_effect = fake_os_path_exists
+        os.path.exists.side_effect = fake_os_path_exists
 
     def test_gets_changelog_path_from_distribution(self):
         """ Should call ‘get_changelog_path’ with distribution. """
-        with self.func_patcher_builtin_open:
-            result = version.has_changelog(self.test_command)
+        result = version.has_changelog(self.test_command)
         version.get_changelog_path.assert_called_with(
                 self.test_distribution)
 
     def test_returns_expected_result(self):
         """ Should be a subclass of ‘distutils.cmd.Command’. """
-        with self.func_patcher_builtin_open:
-            result = version.has_changelog(self.test_command)
+        result = version.has_changelog(self.test_command)
         self.assertEqual(self.expected_result, result)
 
-    def test_closes_changelog(self):
-        """ Should close the changelog opened for interrogation. """
-        if getattr(self, 'open_scenario', None) != 'success':
-            self.skipTest("File is not opened, no need to close")
-        with self.func_patcher_builtin_open:
-            result = version.has_changelog(self.test_command)
-        self.assertTrue(self.fake_changelog_file.closed)
-
 
 @mock.patch.object(version, 'generate_version_info_from_changelog')
 @mock.patch.object(version, 'serialise_version_info_from_mapping')
