@@ -31,6 +31,7 @@ from __future__ import (absolute_import, unicode_literals)
 
 import sys
 import os
+import io
 import errno
 import json
 import datetime
@@ -402,14 +403,16 @@ def generate_version_info_from_changelog(infile_path):
         :return: The generated version info mapping; or ``None`` if the
             file cannot be read.
 
+        The document is explicitly opened as UTF-8 encoded text.
+
         """
     version_info = collections.OrderedDict()
 
     versions_all_json = None
     try:
-        with open(infile_path, 'rt') as infile:
+        with io.open(infile_path, 'rt', encoding="utf-8") as infile:
             versions_all_json = changelog_to_version_info_collection(infile)
-    except OSError:
+    except EnvironmentError:
         # If we can't read the input file, leave the collection empty.
         pass
 
@@ -471,20 +474,13 @@ def get_changelog_path(distribution, filename=changelog_filename):
 
 
 def has_changelog(command):
-    """ Return ``True`` iff the distribution's changelog is readable. """
+    """ Return ``True`` iff the distribution's changelog file exists. """
     result = False
+
     changelog_path = get_changelog_path(command.distribution)
     if changelog_path is not None:
-        changelog = None
-        try:
-            changelog = open(changelog_path, 'rt')
-        except OSError:
-            # Not able to open the file for reading.
-            pass
-
-        if changelog is not None:
+        if os.path.exists(changelog_path):
             result = True
-            changelog.close()
 
     return result
 
